@@ -13,3 +13,9 @@ class UnableToExtractError(RuntimeError):
 class UnknownLanguageException(Exception):
     """Raised when the input language is invalid"""
     pass
+
+class BadContentError(RuntimeError):
+    """
+    Thrown when the content is not suitable for parsing, ie: too short 
+    """
+    pass
\ No newline at end of file
