@@ -31,6 +31,10 @@ blog_domain_pattern = re.compile(
         r'|\.shinyapps\.io', re.I)
 
 
+def _is_suffix_only_parsed_url(parsed_url) -> bool:
+    return (len(parsed_url.domain) == 0) and (len(parsed_url.subdomain) == 0) and (len(parsed_url.suffix)) > 0
+
+
 def canonical_domain(raw_url: str) -> str:
     """
     Return a useful canonical domain name given a url. In general this is the logical unique part of the domain.
@@ -69,6 +73,12 @@ def canonical_domain(raw_url: str) -> str:
             replace('--', '-')
         candidate_domain = candidate_domain.replace("-", ".")
 
+    # handle exceptions
+    if candidate_domain == '':
+        # country-level domains like gov.cn
+        if _is_suffix_only_parsed_url(parsed_domain):
+            candidate_domain = parsed_domain.suffix
+
     return candidate_domain
 
 
@@ -187,7 +197,7 @@ def _remove_query_params(url: str) -> str:
 
 
 archive_url_pattern = re.compile(r'^https://archive.is/[a-z0-9]/[a-z0-9]+/(.*)', re.I)
-another_url_pattern = re.compile(r'^(https?://)(m|beta|media|data|image|www?|cdn|topic|article|news|archive|blog|video|search|preview|login|shop|sports?|act|donate|press|web|photos?|\d+?).?\.(.*\.)', re.I)
+another_url_pattern = re.compile(r'^(https?://)(m|beta|media|data|image|www|cdn|topic|article|news|archive|blog|video|search|preview|login|shop|sports?|act|donate|press|web|photos?|\d+?).?\.(.*\.)', re.I)
 podomatic_url_pattern = re.compile(r'http://.*pron.*\.podomatic\.com', re.I)
 anchor_url_pattern = re.compile(r'#.*')
 multiple_slashes_url_pattern = re.compile(r'(//.*/)/+', re.I)
